Class: Google::Cloud::AccessApproval::V1::AccessLocations

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/accessapproval/v1/accessapproval.rb

Overview

Home office and physical location of the principal.

Instance Attribute Summary collapse

Instance Attribute Details

#principal_office_country ⇒ ::String

Returns The "home office" location of the principal. A two-letter country code (ISO 3166-1 alpha-2), such as "US", "DE" or "GB" or a region code. In some limited situations Google systems may refer refer to a region code instead of a country code. Possible Region Codes:

* ASI: Asia
* EUR: Europe
* OCE: Oceania
* AFR: Africa
* NAM: North America
* SAM: South America
* ANT: Antarctica
* ANY: Any location.

Returns:

  • (::String) —

    The "home office" location of the principal. A two-letter country code (ISO 3166-1 alpha-2), such as "US", "DE" or "GB" or a region code. In some limited situations Google systems may refer refer to a region code instead of a country code. Possible Region Codes:

    * ASI: Asia
    * EUR: Europe
    * OCE: Oceania
    * AFR: Africa
    * NAM: North America
    * SAM: South America
    * ANT: Antarctica
    * ANY: Any location


57
58
59
60
# File 'proto_docs/google/cloud/accessapproval/v1/accessapproval.rb', line 57

class AccessLocations
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#principal_physical_location_country ⇒ ::String

Returns Physical location of the principal at the time of the access. A two-letter country code (ISO 3166-1 alpha-2), such as "US", "DE" or "GB" or a region code. In some limited situations Google systems may refer refer to a region code instead of a country code. Possible Region Codes:

* ASI: Asia
* EUR: Europe
* OCE: Oceania
* AFR: Africa
* NAM: North America
* SAM: South America
* ANT: Antarctica
* ANY: Any location.

Returns:

  • (::String) —

    Physical location of the principal at the time of the access. A two-letter country code (ISO 3166-1 alpha-2), such as "US", "DE" or "GB" or a region code. In some limited situations Google systems may refer refer to a region code instead of a country code. Possible Region Codes:

    * ASI: Asia
    * EUR: Europe
    * OCE: Oceania
    * AFR: Africa
    * NAM: North America
    * SAM: South America
    * ANT: Antarctica
    * ANY: Any location


57
58
59
60
# File 'proto_docs/google/cloud/accessapproval/v1/accessapproval.rb', line 57

class AccessLocations
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end