Class: Google::Cloud::AccessApproval::V1::EnrolledService

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/accessapproval/v1/accessapproval.rb

Overview

Represents the enrollment of a cloud resource into a specific service.

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_product ⇒ ::String

Returns The product for which Access Approval will be enrolled. Allowed values are listed below (case-sensitive):

* all
* GA
* App Engine
* BigQuery
* Cloud Bigtable
* Cloud Key Management Service
* Compute Engine
* Cloud Dataflow
* Cloud Dataproc
* Cloud DLP
* Cloud EKM
* Cloud HSM
* Cloud Identity and Access Management
* Cloud Logging
* Cloud Pub/Sub
* Cloud Spanner
* Cloud SQL
* Cloud Storage
* Google Kubernetes Engine
* Organization Policy Serivice
* Persistent Disk
* Resource Manager
* Secret Manager
* Speaker ID

Note: These values are supported as input for legacy purposes, but will not be returned from the API.

* all
* ga-only
* appengine.googleapis.com
* bigquery.googleapis.com
* bigtable.googleapis.com
* container.googleapis.com
* cloudkms.googleapis.com
* cloudresourcemanager.googleapis.com
* cloudsql.googleapis.com
* compute.googleapis.com
* dataflow.googleapis.com
* dataproc.googleapis.com
* dlp.googleapis.com
* iam.googleapis.com
* logging.googleapis.com
* orgpolicy.googleapis.com
* pubsub.googleapis.com
* spanner.googleapis.com
* secretmanager.googleapis.com
* speakerid.googleapis.com
* storage.googleapis.com

Calls to UpdateAccessApprovalSettings using 'all' or any of the XXX.googleapis.com will be translated to the associated product name ('all', 'App Engine', etc.).

Note: 'all' will enroll the resource in all products supported at both 'GA' and 'Preview' levels.

More information about levels of support is available at https://cloud.google.com/access-approval/docs/supported-services.

Returns:

  • (::String) —

    The product for which Access Approval will be enrolled. Allowed values are listed below (case-sensitive):

    * all
    * GA
    * App Engine
    * BigQuery
    * Cloud Bigtable
    * Cloud Key Management Service
    * Compute Engine
    * Cloud Dataflow
    * Cloud Dataproc
    * Cloud DLP
    * Cloud EKM
    * Cloud HSM
    * Cloud Identity and Access Management
    * Cloud Logging
    * Cloud Pub/Sub
    * Cloud Spanner
    * Cloud SQL
    * Cloud Storage
    * Google Kubernetes Engine
    * Organization Policy Serivice
    * Persistent Disk
    * Resource Manager
    * Secret Manager
    * Speaker ID
    

    Note: These values are supported as input for legacy purposes, but will not be returned from the API.

    * all
    * ga-only
    * appengine.googleapis.com
    * bigquery.googleapis.com
    * bigtable.googleapis.com
    * container.googleapis.com
    * cloudkms.googleapis.com
    * cloudresourcemanager.googleapis.com
    * cloudsql.googleapis.com
    * compute.googleapis.com
    * dataflow.googleapis.com
    * dataproc.googleapis.com
    * dlp.googleapis.com
    * iam.googleapis.com
    * logging.googleapis.com
    * orgpolicy.googleapis.com
    * pubsub.googleapis.com
    * spanner.googleapis.com
    * secretmanager.googleapis.com
    * speakerid.googleapis.com
    * storage.googleapis.com
    

    Calls to UpdateAccessApprovalSettings using 'all' or any of the XXX.googleapis.com will be translated to the associated product name ('all', 'App Engine', etc.).

    Note: 'all' will enroll the resource in all products supported at both 'GA' and 'Preview' levels.

    More information about levels of support is available at https://cloud.google.com/access-approval/docs/supported-services



288
289
290
291
# File 'proto_docs/google/cloud/accessapproval/v1/accessapproval.rb', line 288

class EnrolledService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enrollment_level ⇒ ::Google::Cloud::AccessApproval::V1::EnrollmentLevel

Returns The enrollment level of the service.

Returns:



288
289
290
291
# File 'proto_docs/google/cloud/accessapproval/v1/accessapproval.rb', line 288

class EnrolledService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end